==> bitfront-library-6.6.2.tgz: package/src/app/shared/component/form/bit-general.component.ts <==
import { Input, Output, EventEmitter, OnInit, SimpleChange } from "@angular/core";
import { FormControl } from "@angular/forms";

import { AyudaService } from "../../service/ayuda.service";

/**
 *  Clase general que todos los componentes personalizados deben extender. Contiene toda la lógica común para trabajar con
 * componentes personalizados
 */
export abstract class BitGeneralComponent implements OnInit {
  @Input()
  control: FormControl;
  @Input()
  nombre: any;
  @Input()
  nombreDirectiva: any;
  @Input()
  label: string;
  @Input()
  estilo: string;
  @Input()
  tooltipTexto: string;
  @Input()
  tooltipPosicion: string;
  @Input()
  ayuda: string; // clave de la ayuda contextual
  @Input()
  placeholder: string = "";
  @Input()
  readOnly: boolean = false;
  @Input()
  hideLabel: boolean = false; // forzar que no se reserve espacio para el nombre del campo
  @Input()
  instanciaPipe: any;
  @Input()
  forceObligatorio: boolean = false;
  @Output()
  onChange = new EventEmitter<string>();

  constructor(protected ayudaService: AyudaService) {}

  /**Debemos suscribirnos a los cambios del FormControl para emitir mediante onChange el evento con el nuevo valor que tiene el componente */
  ngOnInit() {
    if (this.control) {
      this.control.valueChanges.subscribe(value => {
        this.onChange.emit(value);
      });
    } else {
      console.log(`control no definido para ${this.nombre}`);
    }
  }

  /** Controlamos si debemos modificar el valor interno del componente mediante una transformacion al tener un pipe asociado*/
  onBlur() {
    if (this.instanciaPipe != null) {
      this.control.setValue(this.instanciaPipe.transform(this.control.value));
    }
  }

  onFocus() {
    if (this.instanciaPipe != null) {
      this.control.setValue(this.instanciaPipe.parse(this.control.value));
      this.control.updateValueAndValidity();
    }
  }

  // decidimos marcar el campo como obligatorio si se ha indicado a la fuerza (por parámetro)
  // o si el control de formulario asociado está saltando por ser obligatorio y no haberse rellenado
  get obligatorio(): boolean {
    return this.forceObligatorio || (this.control && this.control.errors && this.control.errors["required"]);
  }

  showAyuda() {
    this.ayudaService.mostrarAyuda(this.ayuda);
  }

  get value_lectura(): string {
    return this.control.value;
  }
}

==> bitfront-library-11.0.0.tgz: package/src/app/shared/component/form/bit-general.component.ts <==
import { Input, Output, EventEmitter, OnInit, SimpleChange, Directive } from "@angular/core";
import { FormControl } from "@angular/forms";

import { AyudaService } from "../../service/ayuda.service";

/**
 *  Clase general que todos los componentes personalizados deben extender. Contiene toda la lógica común para trabajar con
 * componentes personalizados
 */
@Directive()
export abstract class BitGeneralComponent implements OnInit {
  @Input()
  control: FormControl;
  @Input()
  nombre: any;
  @Input()
  nombreDirectiva: any;
  @Input()
  label: string;
  @Input()
  estilo: string;
  @Input()
  tooltipTexto: string;
  @Input()
  tooltipPosicion: string;
  @Input()
  ayuda: string; // clave de la ayuda contextual
  @Input()
  placeholder: string = "";
  @Input()
  readOnly: boolean = false;
  @Input()
  hideLabel: boolean = false; // forzar que no se reserve espacio para el nombre del campo
  @Input()
  instanciaPipe: any;
  @Input()
  forceObligatorio: boolean = false;
  @Output()
  onChange = new EventEmitter<string>();

  constructor(protected ayudaService: AyudaService) {}

  /** Debemos suscribirnos a los cambios del FormControl para emitir mediante onChange el evento con el nuevo valor que tiene el componente. */
  ngOnInit() {
    if (this.control) {
      this.transformValue();
      this.control.valueChanges.subscribe(value => {
        this.transformValue();
        this.onChange.emit(value);
      });
    } else {
      console.log(`control no definido para ${this.nombre}`);
    }
  }

  /** Controlamos si debemos modificar el valor interno del componente mediante una transformacion al tener un pipe asociado. */
  onBlur() {
    if (this.instanciaPipe != null) {
      this.control.setValue(this.instanciaPipe.transform(this.control.value));
    }
  }

  onFocus() {
    if (this.instanciaPipe != null) {
      this.control.setValue(this.instanciaPipe.parse(this.control.value));
      this.control.updateValueAndValidity();
    }
  }

  /**
   * Si es necesario, transformamos el valor de entrada para que se muestre correctamente en el campo (ver bit-dropdown-general).
   */
  protected transformValue(): void {}

  // decidimos marcar el campo como obligatorio si se ha indicado a la fuerza (por parámetro)
  // o si el control de formulario asociado está saltando por ser obligatorio y no haberse rellenado
  get obligatorio(): boolean {
    return this.forceObligatorio || (this.control && this.control.errors && this.control.errors["required"]);
  }

  showAyuda() {
    this.ayudaService.mostrarAyuda(this.ayuda);
  }

  get value_lectura(): string {
    return this.control.value;
  }
}
